﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Chapter12
{
    class Chapter15
    {
        // We will NOT have a Main() runtime method here. BUT we will have a parent/base/super method that will have a try/catch

        public static void myFileIO(string firstName, string lastName, string creationDate)  // params1 and 2 will be passed from Chapter12.Main() call of this function, aka the data comes from Chapter12.Main()
        {
            try
            {
                /*
                 * Create a log file of new contact activity to a txt file
                 * filename will be log_MMddyyyy.txt DateTime Class Now
                 * paths can be handled in 2 methods. absolute or relative
                 * Environment Class use to handle the file structure and path to our txt file
                 * firstname, lastname, datetime.Now
                 */

                // Capture the current Env in memory
                string folderPath = Path.Combine(
                    Environment.GetFolderPath(
                        Environment.SpecialFolder.MyDocuments
                        ), // GetFolderPath
                        "LogFiles"
                    ); // Combine
                // C:\Users\Administrator\Documents\LogFiles

                // folderPath to handle directory
                Directory.CreateDirectory( folderPath );

                // Create the filename for the log
                // log_01312024.txt
                string filename = $"log_{DateTime.Now:MMddyyyy}.txt";
                
                string filePath = Path.Combine(folderPath, filename );
                // C:\Users\Administrator\Documents\LogFiles\log_01312024.txt

                // Create the content to write to the file
                /*
                 * col1 -> firstName
                 * col2 -> lastName
                 * col3 -> DateTime.Now as string
                 * 20240512 02:31:30.123456 : 12-05-2024 02:31:30
                 * Bob,Smith,12-05-2024 02:31:30
                 */
                
                string log_content = $"{firstName},{lastName},{creationDate}{Environment.NewLine}";

                // Append the line to the file
                File.AppendAllText(filePath, log_content );

            } // try
            catch (IOException e)
            {
                Console.WriteLine(e.ToString());    
            } // catch

            catch (Exception e) 
            {
                Console.WriteLine(e.ToString());
            } // catch

        } // myFileIO()

    } // class
} // namespace
