﻿/* Best Practices for readability of code
 * 
 * Application -> TitleCase MyApplicationName
 * Factory -> TitleCase Docker/SharePoint...<container>
 * PROVIDERS -> UPPERCASE API/INPUTS/OUTPUTS "provide external sources"
 * Services -> TitleCase WebServices, MicroService, LDAPServices
 * Classes (isolated blocks of reusable code) -> TitleCase
 * Class Object -> "Object Orientated Programming" camelCase or underscore_case -> for loop object
 * variables -> lowercase / camelCase / underscore_case -> switch
 * value -> if
 */

/* Value / Data Types
 * 
 * bit 0 or 1
 * byte 01000001 ->  <128><64><32><16><8><4><2><1>
 * numbers 10000001 -> 129
 * char 01000001<A> 01000010<B> 01000011<C> 01100010<b>
 * string 'B''o''b' list of 3 chars "Bob"
 * 
 * Independent Collection of Strings
 * "Bob","Joe","Mary"
 * List,Set,Tuple,Dictionary
 * 
 * Dependent Collections of Objects
 * 1 Dim -> col <value>  fname 'Bob'
 * 2 Dim -> row/col <value> Contact.fname,Contact.lname -> fname'Bob'
 * 3 Dim -> pivot1 row/col <value> state -> row1.fname,row1.lname -> fname'Bob'
 * 4 Dim -> p2,p1 row/col <value> state/ageGroup -> row/col <value>
 * ... 
 * 7 Dim
 */

// Numbers  0-9
//// int, float<7>, double<14>
//// Numbers will NOT have wrapper
//// ` tick ' single " double

// In C# the data type is EXplicitly defined. aka we are required to define the type
using System.Xml.Schema;

int age = 25; // variable named age has type of integer and ASSIGNED value of 25
// int -> value type <value,data,class,delegate,......>
// age -> variable name
// 25 -> value
// int age; -> property of an object

// Principles of Programming
// Law of Demeter -> dont create an object you do not plan to use
// https://en.wikipedia.org/wiki/Law_of_Demeter
// database connect 50 fields -> fname, lname, age

// 2 base types for decimals
//// float<7> double<14>

double price; // variable price type double; -> memory
price = 52.25; // assigns value 52.25 to obj.price in memory

float cost = 12.54f; // var / type / value assignment ; -> memory

// chars -> strings [a-zA-Z0-9][specials][)!@#$%...]
// `injector 'string  "value" ' `
string firstName = "Bob"; // "value" string
string lastName = "Smith"; 
string state = "Florida";

// TYPES MATTER in OOP languages
// Talk to your friends, not strangers! -> int are not friends with strings. strings not friends with boolean<True/False>
string contactInfo = firstName + cost.ToString(); // string + string
Console.WriteLine(contactInfo); //stdout() -> Terminal
// cost is still a float

// Options when outputting values to view
// Option 1 -> use a join operator +
string fullName1 = firstName + " " + lastName; // Bob Smith
//// Option 1 is harder on cpu/memory controller class
//// Option 1 TYPES MATTER string + string + string
//// Option 1 althought resource intensive, is a better way to go than option 2


// Option 2 -> use template variables {}
string fullName2 = $"{firstName} {lastName} {age}"; // Bob Smith 25
//// Option 2 DO NOT care about the type only the value
//// Option 2 when outputting to a view


